WITH Ada.Text_IO;
WITH Ada.Integer_Text_IO;
WITH Screen;
PROCEDURE Menu_Handler IS
--------------------------------------------------------------
--| Framework for a menu-driven command interpreter
--| Author: M. B. Feldman, The George Washington University 
--| Last Modified: August 1998 
--------------------------------------------------------------

  TYPE Commands IS (A, M, P, Q);
  PACKAGE Command_IO IS 
    NEW Ada.Text_IO.Enumeration_IO (Enum => Commands);

  MenuSelection : Commands;  -- input - a commands

BEGIN -- Menu_Handler

  LOOP   -- this is the outer loop that keeps the program 
         -- running until a "quit" command is entered.

    LOOP -- inner loop continues until valid input is entered
      BEGIN -- exception handler block

        Screen.ClearScreen;
        Screen.MoveCursor (Row => 5, Column => 20);
        Ada.Text_IO.Put (Item => "Main Command Menu");
        Screen.MoveCursor (Row => 7, Column => 20);
        Ada.Text_IO.Put (Item => "A - Compute Average");
        Screen.MoveCursor (Row => 8, Column => 20);
        Ada.Text_IO.Put (Item => "M - Compute Median");    
        Screen.MoveCursor (Row => 9, Column => 20);
        Ada.Text_IO.Put (Item => "P - Plot the data");     
        Screen.MoveCursor (Row => 10, Column => 20);
        Ada.Text_IO.Put (Item => "Q - Quit the program");   

        Screen.MoveCursor (Row => 14, Column => 20);
        Ada.Text_IO.Put ("Enter a command, please > ");

        -- this statement will raise Data_Error if input 
        -- is not one of the valid commands
        Command_IO.Get (Item => MenuSelection);

        -- these statements are executed if command is valid  
        -- otherwise, control passes to exception handler
        Screen.MoveCursor (Row => 17, Column => 20);
        Ada.Text_IO.Put ("Thank you for correct input.");      
        EXIT;      -- valid command; go process it

      EXCEPTION    -- invalid command
      
        WHEN Ada.Text_IO.Data_Error =>
          Screen.MoveCursor (Row => 17, Column => 20);
          Screen.Beep;
          Ada.Text_IO.Put 
            (Item => "Invalid command; please re-enter");
          Ada.Text_IO.Skip_Line;
          Ada.Text_IO.New_Line;
          DELAY 2.0;

      END;         -- of exception handler block
    END LOOP;

    -- We come here if command was valid
    Screen.MoveCursor (Row =>20, Column => 20);

    EXIT WHEN MenuSelection = Q;

    IF MenuSelection = A THEN
      Ada.Text_IO.Put 
        (Item => "Here we would do the average. ");
      Ada.Text_IO.New_Line;
    ELSIF MenuSelection = M THEN
      Ada.Text_IO.Put 
        (Item => "Here we would do the median.  ");
      Ada.Text_IO.New_Line;
    ELSIF MenuSelection = P THEN
      Ada.Text_IO.Put 
        (Item => "Here we would do the plotting.");
      Ada.Text_IO.New_Line;
    END IF;

    DELAY 2.0;

  END LOOP;

  Ada.Text_IO.Put (Item => "Goodbye for today.  ");
  Ada.Text_IO.New_Line;

END Menu_Handler;
