WITH Ada.Text_IO;
WITH Ada.Float_Text_IO;
PROCEDURE Weekly_Pay IS
----------------------------------------------------------------
--| Computes and displays gross pay and net pay given an hourly
--| rate and number of hours worked.  Deducts a tax of 15% of
--| gross salary exceeding $100.
--| Author: Michael Feldman, The George Washington University
--| Last Modified: July 1998
----------------------------------------------------------------
  SUBTYPE NonNegFloat IS Float RANGE 0.0 .. Float'Last;

  TaxBracket : CONSTANT NonNegFloat := 100.00;
                             -- maximum salary for no deduction
  TaxRate:     CONSTANT NonNegFloat :=  0.15;   -- tax rate

  Hours:      NonNegFloat; -- inputs - hours worked, hourly rate
  HourlyRate: NonNegFloat;
  GrossPay:   NonNegFloat; -- outputs - gross pay, net pay
  Tax:        NonNegFloat;
  NetPay:     NonNegFloat;

BEGIN -- Weekly_Pay

  -- Enter Hours and Rate
  Ada.Text_IO.Put (Item => "Hours worked > ");
  Ada.Float_Text_IO.Get (Item => Hours);
  Ada.Text_IO.Put (Item => "Hourly rate $");
  Ada.Float_Text_IO.Get (Item => HourlyRate);
  Ada.Text_IO.New_Line;

  -- Compute gross salary
  GrossPay := Hours * HourlyRate;

  -- Compute tax and net salary
  IF GrossPay > TaxBracket THEN
    Tax := TaxRate * (GrossPay - TaxBracket);
    NetPay := GrossPay - Tax;     -- Deduct a tax amount
  ELSE
    NetPay := GrossPay;           -- Deduct no tax
  END IF;

  -- Display Results
  Ada.Text_IO.Put (Item => "Gross pay is $");
  Ada.Float_Text_IO.Put(Item => GrossPay, Fore => 1, Aft => 2, Exp => 0);
  Ada.Text_IO.New_Line;
  Ada.Text_IO.Put (Item => "TaxDeduction is $");
  Ada.Float_Text_IO.Put (Item => Tax, Fore => 1, Aft => 2, Exp => 0);
  Ada.Text_IO.New_Line;
  Ada.Text_IO.Put (Item => "Net pay is $");
  Ada.Float_Text_IO.Put (Item => NetPay, Fore => 1, Aft => 2, Exp => 0);
  Ada.Text_IO.New_Line;

END Weekly_Pay;


